Crate kcr_app_k8s_io

Crate kcr_app_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the app.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

app.k8s.io/v1beta1

  • Application

Modules

v1beta1